@@ -118,3 +118,9 @@ class TypeLiteral(FakeAnnotation):
         Check if literals have the same children.
         """
         return self.children == other.children
+
+    def get_local_types(self) -> list[FakeAnnotation]:
+        """
+        Get internal types generated by builder.
+        """
+        return [self]
